from .upload_ssm import *

if __name__ == '__main__':
    main(args.profile, args.region, args.keyid, args.file, args.stage)
